# has_familial_relationships

None

URI: https://w3id.org/linkml/tests/kitchen_sink/has_familial_relationships



<!-- no inheritance hierarchy -->


## Properties

 * Range: FamilialRelationship

## Identifier and Mapping Information


